# Overview

Quobyte is a distributed file system that turns commodity servers into a unified software storage system. As a genuine data center file system it supports high-performance workloads ranging from Big Data to VMs. It is completely fault-tolerant and massively scalable.

This charm deploys a metadata service. With the quobyte-registry and quobyte-data charms it forms a Quobyte installation.

The Metadata service stores Volume replicas, usually a Volume is replicated across three Metadata services.

The Metadata service implements all POSIX calls relevant for metadata management, e.g. open, stat, readdir, rename, chmod, chown, etc.

# Usage

The quobyte-metadata charm has three mandatory configuration items. Without them, the installation will not go through.

    repo_id:
        In order to access your Quobyte packages an id from your Quobyte support account is integrated into the package repository path. You can fetch your repo_id at https://support.quobyte.com

    quobyte-license-accepted:
        Set parameter to accept the Quobyte License, obtainable at http://www.quobyte.com/cloud/juju/assets/license

    oracle-java-license-accepted:
        Quobyte depends on an Oracle Java 8 Installation. The charm installs Java, when the Oracle Java License is accepted by setting this variable to True. You may obtain a copy of the license at http://java.com/license

The quobyte-metadata charm makes use of the [Storage support](https://jujucharms.com/docs/stable/storage) in Juju which allows you to specify the used storage and size.

Here's an example: in order to deploy the Metadata service on 3 machines using Amazon EBS with 1TB per instance on EC2, type:

    juju deploy quobyte-metadata qb-meta --storage metadata-storage=ebs,1024G
    juju add-unit -n2 qb-meta
    juju set qb-meta repo_id=<repo_id>
    juju set qb-meta oracle-java-license-accepted=true

By adding a relation with a deployed quobyte-registry charm, the quobyte-metadata charm is configured, e.g. for a Registry service named qb-reg and a Metadata Service named qb-meta:

    juju add-relation qb-reg qb-data

## Scale out Usage

To add storage to a deployed unit, e.g. 3 EBS devices with 1TB each to a unit qb-meta/1: 

    juju storage add qb-meta/1 metadata-storage=ebs,1024G,3

To add another instance of the Data service, one can add another unit to an already deployed service: 

    juju add-unit qb-meta

or deploy the quobyte-data charm again and add a relation to the Registry service as shown above.

# Contact Information

To contact [Quobyte](http://www.quobyte.com) you can drop us a line [here](http://www.quobyte.com/contact).

Charm authors:
- [Bruno Ranieri](https://launchpad.net/~3-bruno/+contactuser)	
